pub struct Rect { /* private fields */ }Implementations
Sourceimpl Rect
impl Rect
pub fn try_downcast(element: &dyn ElementExt) -> Option<RectElement>
Sourcepub fn color(self, color: impl Into<Fill>) -> Self
pub fn color(self, color: impl Into<Fill>) -> Self
Set the fill of text rendered inside the rect and inherited by its children. See Fill.
Sourcepub fn font_size(self, font_size: impl Into<FontSize>) -> Self
pub fn font_size(self, font_size: impl Into<FontSize>) -> Self
Set the size of text rendered inside the rect and inherited by its children. See FontSize.
Sourcepub fn overflow<S: Into<Overflow>>(self, overflow: S) -> Self
pub fn overflow<S: Into<Overflow>>(self, overflow: S) -> Self
Set whether content overflowing the rect’s bounds is clipped. See Overflow.
Sourcepub fn rotate<R: Into<Option<f32>>>(self, rotation: R) -> Self
pub fn rotate<R: Into<Option<f32>>>(self, rotation: R) -> Self
Rotate the rect by the given angle in degrees.
Sourcepub fn transform_origin(
self,
transform_origin: impl Into<TransformOrigin>,
) -> Self
pub fn transform_origin( self, transform_origin: impl Into<TransformOrigin>, ) -> Self
Set the point that the scale and rotation effects pivot around.
Defaults to the element’s center.